@@ -29,6 +29,7 @@ import (
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/columns"
 	containercollection "github.com/inspektor-gadget/inspektor-gadget/pkg/container-collection"
 	containerutilsTypes "github.com/inspektor-gadget/inspektor-gadget/pkg/container-utils/types"
+	"github.com/inspektor-gadget/inspektor-gadget/pkg/types"
 	"github.com/inspektor-gadget/inspektor-gadget/pkg/utils/host"
 )
 
@@ -59,6 +60,13 @@ func NewListContainersCmd() *cobra.Command {
 				Runtime: containercollection.RuntimeSelector{
 					ContainerName: commonFlags.Containername,
 				},
+				K8s: containercollection.K8sSelector{
+					BasicK8sMetadata: types.BasicK8sMetadata{
+						PodName:       commonFlags.K8sPodName,
+						Namespace:     commonFlags.K8sNamespace,
+						ContainerName: commonFlags.K8sContainerName,
+					},
+				},
 			}
 
 			if !optionWatch {
