@@ -51,8 +51,10 @@ func TestFdpassGadget(t *testing.T) {
 			generateEvent: generateEvent,
 			validateEvent: func(t *testing.T, info *utils.RunnerInfo, inodeNum uint64, sockfd int, fd int, events []ExpectedFdpassEvent) {
 				utils.ExpectAtLeastOneEvent(func(info *utils.RunnerInfo, fd int) *ExpectedFdpassEvent {
+					proc := info.Proc
+					utils.NormalizeParentTid(&proc)
 					return &ExpectedFdpassEvent{
-						Proc:      info.Proc,
+						Proc:      proc,
 						SocketIno: inodeNum,
 						Sockfd:    uint32(sockfd),
 						Fd:        uint32(fd),
@@ -85,11 +87,15 @@ func TestFdpassGadget(t *testing.T) {
 				})
 				return nil
 			}
+			normalizeEvent := func(event *ExpectedFdpassEvent) {
+				utils.NormalizeParentTid(&event.Proc)
+			}
 			opts := gadgetrunner.GadgetRunnerOpts[ExpectedFdpassEvent]{
 				Image:          "fdpass",
 				Timeout:        5 * time.Second,
 				MntnsFilterMap: mntnsFilterMap,
 				OnGadgetRun:    onGadgetRun,
+				NormalizeEvent: normalizeEvent,
 			}
 			gadgetRunner := gadgetrunner.NewGadgetRunner(t, opts)
 
