@@ -63,8 +63,10 @@ func TestTopFileGadget(t *testing.T) {
 			},
 			validateEvent: func(t *testing.T, info *utils.RunnerInfo, filepath string, events []ExpectedTopFileEvent) {
 				utils.ExpectAtLeastOneEvent(func(info *utils.RunnerInfo, pid int) *ExpectedTopFileEvent {
+					proc := info.Proc
+					utils.NormalizeParentTid(&proc)
 					return &ExpectedTopFileEvent{
-						Proc: info.Proc,
+						Proc: proc,
 						T:    "R",
 						File: filepath,
 
@@ -97,6 +99,7 @@ func TestTopFileGadget(t *testing.T) {
 			}
 			normalizeEvent := func(event *ExpectedTopFileEvent) {
 				utils.NormalizeInt(&event.Writes)
+				utils.NormalizeParentTid(&event.Proc)
 			}
 			onGadgetRun := func(gadgetCtx operators.GadgetContext) error {
 				utils.RunWithRunner(t, runner, func() error {
